*******
Credits
*******

Acknowledgments
===============
We would like to thank all contributors and supporters of this project.

Authors
=======
- Alessandra Trapani (alessandra.trapani@catalystneuro.com)
- Cody Baker (cody.baker@catalystneuro.com)

*****
Legal
*****

License
=======
This project is licensed under the BSD-3 License. See the LICENSE.txt file for details.
